==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ConsoleSpecFluent<A extends ConsoleSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAuthentication instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleAuthentication getAuthentication();
  public ConsoleAuthentication buildAuthentication();
  public A withAuthentication(ConsoleAuthentication authentication);
  public Boolean hasAuthentication();
  public A withNewAuthentication(String logoutRedirect);
  public ConsoleSpecFluent.AuthenticationNested<A> withNewAuthentication();
  public ConsoleSpecFluent.AuthenticationNested<A> withNewAuthenticationLike(ConsoleAuthentication item);
  public ConsoleSpecFluent.AuthenticationNested<A> editAuthentication();
  public ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthentication();
  public ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthenticationLike(ConsoleAuthentication item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AuthenticationNested<N> extends Nested<N>,ConsoleAuthenticationFluent<ConsoleSpecFluent.AuthenticationNested<N>>{
    public N and();
    public N endAuthentication();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsoleSpecFluent<A extends ConsoleSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAuthentication instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleAuthentication getAuthentication();
  public ConsoleAuthentication buildAuthentication();
  public A withAuthentication(ConsoleAuthentication authentication);
  public Boolean hasAuthentication();
  public A withNewAuthentication(String logoutRedirect);
  public ConsoleSpecFluent.AuthenticationNested<A> withNewAuthentication();
  public ConsoleSpecFluent.AuthenticationNested<A> withNewAuthenticationLike(ConsoleAuthentication item);
  public ConsoleSpecFluent.AuthenticationNested<A> editAuthentication();
  public ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthentication();
  public ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthenticationLike(ConsoleAuthentication item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AuthenticationNested<N> extends Nested<N>,ConsoleAuthenticationFluent<ConsoleSpecFluent.AuthenticationNested<N>>{
    public N and();
    public N endAuthentication();
    
  }
  
}
